@@ -7,12 +7,13 @@ from _geckoDriver import GeckoDriver
 from _operaDriver import OperaDriver
 from _edgeDriver import EdgeDriver
 from _chromiumChromeDriver import ChromiumChromeDriver
+from _phantomJS import PhantomJS
 from _setting import setting
 
 import logging
 import os
 import traceback
-from typing import Tuple, Union
+from typing import Tuple
 
 import time
 
@@ -25,9 +26,10 @@ class DriverUpdater():
     operadriver = 'operadriver'
     edgedriver = 'edgedriver'
     chromium_chromedriver = 'chromium-chromedriver'
+    phantomjs = 'phantomjs'
         
     @staticmethod
-    def install(driver_name : Union[str, list[str]], **kwargs):
+    def install(driver_name, **kwargs):
         """Function for install or update Selenium driver binary
 
         Args:
@@ -57,7 +59,7 @@ class DriverUpdater():
         #Initialize all variables
         result_run : bool = False
         message_run : str = ''
-        driver_path : str = ''
+        driver_path = ''
 
         info_messages = bool(kwargs.get('info_messages', True))
         if info_messages:
@@ -69,7 +71,8 @@ class DriverUpdater():
         logging.info('You have not specified the path - so used default folder path instead') if not kwargs.get('path') else ''
         path = str(os.path.abspath(path) + os.path.sep)
 
-        filename : str = str(kwargs.get('filename', '')).replace('.', '')
+        filename : str = str(kwargs.get('filename', '')).replace('.', '') if type(kwargs.get('filename', '')) == str else\
+                         kwargs.get('filename', '') if type(kwargs.get('filename', '')) == list else ''
 
         enable_library_update_check = bool(kwargs.get('enable_library_update_check', True))
         upgrade = bool(kwargs.get('upgrade', False))
@@ -80,7 +83,7 @@ class DriverUpdater():
 
         try:
 
-            result, message = DriverUpdater.__check_enviroment_and_variables(path=path, driver_name=driver_name, enable_library_update_check=enable_library_update_check)
+            result, message = DriverUpdater.__check_enviroment_and_variables(path=path, driver_name=driver_name, enable_library_update_check=enable_library_update_check, filename=filename)
             if not result:
                 logging.error(message)
                 return result, message, driver_path
@@ -90,25 +93,34 @@ class DriverUpdater():
                 result, message, driver_path = DriverUpdater.__run_specific_driver(driver_name=driver_name, path=path, upgrade=upgrade, chmod=chmod, 
                                                 check_driver_is_up_to_date=check_driver_is_up_to_date, 
                                                 filename=filename, version=version,
-                                                check_browser_is_up_to_date=check_browser_is_up_to_date)
+                                                check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                 if not result:
                     logging.error(message)
                     return result, message, driver_path
 
             elif type(driver_name) == list:
+
+                list_of_paths : list[str] = []
                 
                 for driver in driver_name:
 
                     time.sleep(1) #small sleep
 
+                    filename_driver = str(filename[driver_name.index(driver)]) if len(filename) > driver_name.index(driver) and filename else ''
+                    filename_driver.replace('.', '')
+
                     result, message, driver_path = DriverUpdater.__run_specific_driver(driver_name=driver, path=path, upgrade=upgrade, chmod=chmod, 
                                                 check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                                filename=filename, version=version,
-                                                check_browser_is_up_to_date=check_browser_is_up_to_date)
+                                                filename=filename_driver, version=version,
+                                                check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                     if not result:
                         logging.error(message)
                         return result, message, driver_path
 
+                    list_of_paths.append(driver_path)
+
+                driver_path = list_of_paths
+
             result_run = True
 
         except:
@@ -118,7 +130,7 @@ class DriverUpdater():
         return result_run, message_run, driver_path
 
     @staticmethod
-    def __check_all_input_parameteres(path, driver_name) -> Tuple[bool, str]:
+    def __check_all_input_parameteres(path, driver_name, filename) -> Tuple[bool, str]:
         """Private function for checking all input parameters
 
         Args:
@@ -157,17 +169,25 @@ class DriverUpdater():
 
             if type(driver_name) == str:
 
-                driver_name_check =      DriverUpdater.chromedriver if DriverUpdater.chromedriver == driver_name else \
+                driver_name_check =     DriverUpdater.chromedriver if DriverUpdater.chromedriver == driver_name else \
                                         DriverUpdater.geckodriver  if DriverUpdater.geckodriver == driver_name else \
                                         DriverUpdater.operadriver if DriverUpdater.operadriver == driver_name else \
                                         DriverUpdater.edgedriver if DriverUpdater.edgedriver == driver_name else \
-                                        DriverUpdater.chromium_chromedriver if DriverUpdater.chromium_chromedriver == driver_name else ''
+                                        DriverUpdater.chromium_chromedriver if DriverUpdater.chromium_chromedriver == driver_name else \
+                                        DriverUpdater.phantomjs if DriverUpdater.phantomjs == driver_name else ''
 
                 if not driver_name_check:
                     message = f'Unknown driver name was specified current driver_name is: {driver_name}'
                     logging.error(message)
                     return result_run, message
 
+                if filename:
+
+                    if type(filename) != str:
+                        message = f'Unknown type of filename was specificed type(filename): {type(filename)}, but must be str, if one driver is given'
+                        logging.error(message)
+                        return result_run, message
+
             elif type(driver_name) == list:
 
                 for driver in driver_name:
@@ -176,13 +196,21 @@ class DriverUpdater():
                                             DriverUpdater.geckodriver  if DriverUpdater.geckodriver == driver else \
                                             DriverUpdater.operadriver if DriverUpdater.operadriver == driver else \
                                             DriverUpdater.edgedriver if DriverUpdater.edgedriver == driver else \
-                                            DriverUpdater.chromium_chromedriver if DriverUpdater.chromium_chromedriver == driver else ''
+                                            DriverUpdater.chromium_chromedriver if DriverUpdater.chromium_chromedriver == driver else \
+                                            DriverUpdater.phantomjs if DriverUpdater.phantomjs == driver else ''
 
                     if not driver_name_list:
                         message = f'Unknown driver name was specified at index: {driver_name.index(driver)} current name of driver is: {driver}'
                         logging.error(message)
                         return result_run, message
 
+                if filename:
+
+                    if type(filename) != list:
+                        message = f'Unknown type of filename was specificed type(filename): {type(filename)}, but must be list[str], if multiply drivers were given'
+                        logging.error(message)
+                        return result_run, message
+
             else:
 
                 message = f'Unknown type of driver name was specified, this library only supports str or list[str], current type is: {type(driver_name)}'
@@ -223,17 +251,24 @@ class DriverUpdater():
                 logging.error(message)
                 return result, message
 
-            current_version = setting["Program"]["version"]
+            current_version = setting["Program"]["version"].replace('b', '')
             latest_version = json_data.get('info').get('version')
 
-            if latest_version != current_version:
-                message = ('Your selenium-driver-updater library is out of date, please update it. '
+            current_version_tuple = tuple(map(int, (current_version.split("."))))
+            latest_version_tuple = tuple(map(int, (latest_version.split("."))))
+
+            if latest_version_tuple > current_version_tuple:
+                message = ('Your selenium-driver-updater library is out of date, please update it via "pip install selenium-driver-updater --upgrade" '
                            f'current_version: {current_version} latest_version: {latest_version} ')
                 logging.warning(message)
 
-            elif latest_version == current_version:
+            elif latest_version_tuple == current_version_tuple:
                 message = 'Your selenium-driver-updater library is up to date.'
                 logging.info(message)
+            
+            else:
+                message = 'Unable to compare the latest version and current version of the library, maybe you are using a beta version.'
+                logging.error(message)
 
             result_run = True
 
@@ -282,7 +317,7 @@ class DriverUpdater():
         return result_run, message_run
 
     @staticmethod
-    def __check_enviroment_and_variables(path : str, driver_name : Union[str, list[str]], enable_library_update_check : bool) -> Tuple[bool, str]:
+    def __check_enviroment_and_variables(path : str, driver_name, enable_library_update_check : bool, filename) -> Tuple[bool, str]:
         """Private function for checking all input parameters and enviroment
 
         Args:
@@ -317,7 +352,7 @@ class DriverUpdater():
                     logging.error(message)
                     return result, message
 
-            result, message = DriverUpdater.__check_all_input_parameteres(path=path, driver_name=driver_name)
+            result, message = DriverUpdater.__check_all_input_parameteres(path=path, driver_name=driver_name, filename=filename)
             if not result:
                 logging.error(message)
                 return result, message
@@ -368,6 +403,7 @@ class DriverUpdater():
         filename = kwargs.get('filename')
         version = kwargs.get('version')
         check_browser_is_up_to_date = kwargs.get('check_browser_is_up_to_date')
+        info_messages = kwargs.get('info_messages')
         driver_path : str = ''
 
         try:
@@ -377,7 +413,7 @@ class DriverUpdater():
                 chrome_driver = ChromeDriver(path=path, upgrade=upgrade, chmod=chmod, 
                                             check_driver_is_up_to_date=check_driver_is_up_to_date, 
                                             filename=filename, version=version,
-                                            check_browser_is_up_to_date=check_browser_is_up_to_date)
+                                            check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                 result, message, driver_path = chrome_driver.main()
                 if not result:
                     logging.error(message)
@@ -388,7 +424,7 @@ class DriverUpdater():
                 gecko_driver = GeckoDriver(path=path, upgrade=upgrade, chmod=chmod, 
                                         check_driver_is_up_to_date=check_driver_is_up_to_date, 
                                         filename=filename, version=version,
-                                        check_browser_is_up_to_date=check_browser_is_up_to_date)
+                                        check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                 result, message, driver_path = gecko_driver.main()
                 if not result:
                     logging.error(message)
@@ -399,7 +435,7 @@ class DriverUpdater():
                 opera_driver = OperaDriver(path=path, upgrade=upgrade, chmod=chmod, 
                                         check_driver_is_up_to_date=check_driver_is_up_to_date, 
                                         filename=filename, version=version,
-                                        check_browser_is_up_to_date=check_browser_is_up_to_date)
+                                        check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                 result, message, driver_path = opera_driver.main()
                 if not result:
                     logging.error(message)
@@ -410,7 +446,7 @@ class DriverUpdater():
                 edge_driver = EdgeDriver(path=path, upgrade=upgrade, chmod=chmod, 
                                     check_driver_is_up_to_date=check_driver_is_up_to_date, 
                                     filename=filename, version=version,
-                                    check_browser_is_up_to_date=check_browser_is_up_to_date)
+                                    check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                 result, message, driver_path = edge_driver.main()
                 if not result:
                     logging.error(message)
@@ -418,15 +454,23 @@ class DriverUpdater():
 
             elif DriverUpdater.chromium_chromedriver == driver_name:
 
-                chromium_chromedriver = ChromiumChromeDriver(path=path, upgrade=upgrade, chmod=chmod, 
-                                    check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                    filename=filename, version=version,
-                                    check_browser_is_up_to_date=check_browser_is_up_to_date)
+                chromium_chromedriver = ChromiumChromeDriver(check_driver_is_up_to_date=check_driver_is_up_to_date, 
+                                                            check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
                 result, message, driver_path = chromium_chromedriver.main()
                 if not result:
                     logging.error(message)
                     return result, message, driver_path
 
+            elif DriverUpdater.phantomjs == driver_name:
+
+                phantomjs = PhantomJS(path=path, upgrade=upgrade, chmod=chmod, 
+                                    check_driver_is_up_to_date=check_driver_is_up_to_date, 
+                                    filename=filename, version=version, info_messages=info_messages)
+                result, message, driver_path = phantomjs.main()
+                if not result:
+                    logging.error(message)
+                    return result, message, driver_path
+
             result_run = True
 
         except:
